const redis = require('async-redis');
const logger = require('tracer').console();

module.exports = class RedisClient {

    constructor(redis_conf) {
        if (redis_conf) this.init(redis_conf);
    }

    init(redis_conf) {
        this.client = redis.createClient(redis_conf.port, redis_conf.host);
        this.client.on("error", err => logger.error(err));
        this.client.on("connect", () => logger.log("redis service connected " + this.client.address));
        return this.client;
    }

    /**
     * 配置redis ip 端口
     * @param {string} port 
     * @param {string} host 
     */
    static setConf(host, port = '6379') {
        if (!host) logger.error("[REDIS MESSAGE]:Please set up the redis configuration!");
        else if (typeof port !== 'string' || typeof host !== 'string') logger.error("[REDIS MESSAGE]:Check the configuration of redis!");
        else return RedisClient.conf = RedisClient.conf ? RedisClient.conf : { port: port, host: host };
    }

    /**
     * redis 静态单例
     */
    static getInstance() {
        if (!RedisClient.conf) RedisClient.setConf();
        return RedisClient.instance ? RedisClient.instance : new RedisClient(RedisClient.conf);
    }
}




